#
# spec file for package valgrind
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# during building the major version of glibc is built into the suppression file
%define glibc_main_version %(getconf GNU_LIBC_VERSION | cut -d' ' -f2 | cut -d. -f1)
%define glibc_major_version %(getconf GNU_LIBC_VERSION | cut -d' ' -f2 | cut -d. -f2)
%define building_docs 1

Name:           valgrind
Version:        3.15.0
Release:        lp151.4.3.1
Summary:        Memory Management Debugger
License:        GPL-2.0-or-later
Group:          Development/Tools/Debuggers
Url:            http://valgrind.org/
Source0:        ftp://sourceware.org/pub/valgrind/valgrind-%{version}.tar.bz2
# https://bugs.kde.org/show_bug.cgi?id=390553
# https://github.com/olafhering/valgrind/compare/olh-base-master...olh-fixes-master
Patch0:         valgrind.xen.patch
Patch1:         jit-register-unregister.diff
Patch2:         armv6-support.diff
BuildRequires:  automake
BuildRequires:  docbook-xsl-stylesheets
BuildRequires:  docbook_4
%if 0%{?suse_version} < 1320
BuildRequires:  gcc8-c++
%else
BuildRequires:  gcc-c++
%endif
BuildRequires:  libxslt
BuildRequires:  pkgconfig
BuildRequires:  procps
Requires:       glibc >= %{glibc_main_version}.%{glibc_major_version}
Requires:       glibc < %{glibc_main_version}.%{lua:print(rpm.expand("%{glibc_major_version}")+1)}
Provides:       callgrind = %{version}
Obsoletes:      callgrind < %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
ExclusiveArch:  aarch64 %ix86 x86_64 ppc ppc64 ppc64le s390x armv7l armv7hl armv6l armv6hl
%ifarch x86_64 ppc64
%if 0%{?suse_version} < 1320
BuildRequires:  gcc8-c++-32bit
%else
BuildRequires:  gcc-c++-32bit
%endif
BuildRequires:  glibc-devel-32bit
%endif

%description
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the %{_docdir}/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.

%package devel
Summary:        Memory Management Debugger
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}

%description devel
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the %{_docdir}/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.

%ifarch x86_64 ppc64 s390x
%package 32bit
Summary:        Memory Management Debugger
Group:          Development/Tools/Debuggers
Requires:       %{name} = %{version}
Provides:       valgrind:%{_libdir}/valgrind/32bit-core.xml

%description 32bit
Valgrind checks all memory operations in an application, like read,
write, malloc, new, free, and delete. Valgrind can find uses of
uninitialized memory, access to already freed memory, overflows,
illegal stack operations, memory leaks, and any illegal
new/malloc/free/delete commands. Another program in the package is
"cachegrind," a profiler based on the valgrind engine.

To use valgrind you should compile your application with "-g -O0"
compiler options. Afterwards you can use it with:

valgrind --tool=memcheck --sloppy-malloc=yes --leak-check=yes
--db-attach=yes my_application, for example.

More valgrind options can be listed via "valgrind --help". There is
also complete documentation in the %{_docdir}/valgrind/
directory. A debugged application runs slower and needs much more
memory, but is usually still usable. Valgrind is still in development,
but it has been successfully used to optimize several KDE applications.


%endif

%prep
%setup -q
%patch0 -p1
# needs porting to 3.11
##%patch1
%patch2

%build
%define _lto_cflags %{nil}
%if 0%{?suse_version} < 1320
export CC="%{_bindir}/gcc-8"
export CXX="%{_bindir}/g++-8"
%endif

export FLAGS="%{optflags}"
%ifarch %arm
# Valgrind doesn't support compiling for Thumb yet. Remove when it gets
# native thumb support.
FLAGS=${FLAGS/-mthumb/-mthumb-interwork -marm}
%endif
# not a good idea to build valgrind with fortify, as it does not link glibc
FLAGS="${FLAGS/-D_FORTIFY_SOURCE=2/}"
FLAGS="${FLAGS/-fstack-protector-strong/}"
FLAGS="${FLAGS/-fstack-protector/}"
# -m64 / -m32 is set explicitly everywhere, do not override it
FLAGS="${FLAGS/-m64/}"
export CFLAGS="$FLAGS"
export CXXFLAGS="$FLAGS"
export FFLAGS="$FLAGS"
autoreconf -fi

export GDB=%{_bindir}/gdb
%configure \
    --enable-lto=yes \
%ifarch aarch64
    --enable-only64bit \
%endif
    %{nil}

make %{?_smp_mflags}
%if %{building_docs}
pushd docs
    #make all-docs
    # building the docs needs network access at the moment :-(
    make FAQ.txt man-pages html-docs
popd
%endif

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
rm %{buildroot}/%{_libdir}/valgrind/lib*.a # drop unreproducible unused files to fix boo#1118163
mkdir -p %{buildroot}/%{_defaultdocdir}
if test -d %{buildroot}%{_datadir}/doc/valgrind; then
     mv %{buildroot}%{_datadir}/doc/valgrind %{buildroot}/%{_defaultdocdir}
fi
mkdir -p %{buildroot}%{_docdir}/%{name}
cp -a README* NEWS AUTHORS %{buildroot}/%{_defaultdocdir}/%{name}

%check
# OBS doesn't have a z13
%ifnarch s390x
# has too many spurious failures
# make %{?_smp_mflags} regtest
#patent pending self test
VALGRIND_LIB=$PWD/.in_place VALGRIND_LIB_INNER=$PWD/.in_place ./coregrind/valgrind  /usr/bin/perl -wc tests/vg_regtest
%endif

%files devel
%{_includedir}/valgrind
%{_libdir}/pkgconfig/valgrind.pc

%files
%license COPYING COPYING.DOCS
%{_bindir}/*
%doc %{_defaultdocdir}/%{name}
%doc %{_mandir}/*/*
%dir %{_libdir}/valgrind
%ifarch aarch64
%{_libdir}/valgrind/*-arm64-linux
%endif
%ifarch x86_64
%{_libdir}/valgrind/*-amd64-linux
%endif
%ifarch %ix86
%{_libdir}/valgrind/*-x86-linux
%endif
%ifarch ppc
%{_libdir}/valgrind/*-ppc32-linux
%endif
%ifarch ppc64
%{_libdir}/valgrind/*-ppc64be-linux
%endif
%ifarch ppc64le
%{_libdir}/valgrind/*-ppc64le-linux
%endif
%ifarch s390x
%{_libdir}/valgrind/*-s390x-linux
%endif
%ifarch %arm
%{_libdir}/valgrind/*-arm-linux
%endif
%dir /usr/lib/valgrind
/usr/lib/valgrind/dh_view*
%{_libdir}/valgrind/*-linux.so
%{_libdir}/valgrind/*.supp
%{_libdir}/valgrind/64bit-core.xml
%{_libdir}/valgrind/64bit-linux.xml
%{_libdir}/valgrind/64bit-sse.xml
%{_libdir}/valgrind/64bit-core-valgrind-s*.xml
%{_libdir}/valgrind/64bit-linux-valgrind-s*.xml
%{_libdir}/valgrind/64bit-sse-valgrind-s*.xml
%{_libdir}/valgrind/amd64-coresse-valgrind.xml
%{_libdir}/valgrind/amd64-linux-valgrind.xml
%{_libdir}/valgrind/power64-core-valgrind-s*.xml
%{_libdir}/valgrind/power64-core.xml
%{_libdir}/valgrind/power64-core2-valgrind-s*.xml
%{_libdir}/valgrind/power64-linux-valgrind-s*.xml
%{_libdir}/valgrind/power64-linux.xml
%{_libdir}/valgrind/64bit-avx-valgrind-s*.xml
%{_libdir}/valgrind/64bit-avx.xml
%{_libdir}/valgrind/amd64-avx-coresse-valgrind.xml
%{_libdir}/valgrind/amd64-avx-coresse.xml
%{_libdir}/valgrind/amd64-avx-linux-valgrind.xml
%{_libdir}/valgrind/amd64-avx-linux.xml
%{_libdir}/valgrind/mips64-cp0-valgrind-s*.xml
%{_libdir}/valgrind/mips64-cp0.xml
%{_libdir}/valgrind/mips64-cpu-valgrind-s*.xml
%{_libdir}/valgrind/mips64-cpu.xml
%{_libdir}/valgrind/mips64-fpu-valgrind-s*.xml
%{_libdir}/valgrind/mips64-fpu.xml
%{_libdir}/valgrind/mips64-linux-valgrind.xml
%{_libdir}/valgrind/mips64-linux.xml
%{_libdir}/valgrind/power-core-valgrind-s*.xml
%{_libdir}/valgrind/s390x-core64-valgrind-s*.xml
%{_libdir}/valgrind/s390x-core64.xml
%{_libdir}/valgrind/s390x-generic-valgrind.xml
%{_libdir}/valgrind/s390x-generic.xml
%{_libdir}/valgrind/s390x-linux64-valgrind-s*.xml
%{_libdir}/valgrind/s390x-linux64.xml
%{_libdir}/valgrind/s390x-vx-linux-valgrind.xml
%{_libdir}/valgrind/s390x-vx-linux.xml

%ifarch x86_64 ppc64 s390x
%files 32bit
%endif
%ifarch %ix86 x86_64
%{_libdir}/valgrind/*-x86-linux
%endif
%ifarch ppc ppc64
%{_libdir}/valgrind/*-ppc32-linux
%endif
%{_libdir}/valgrind/s390-acr-valgrind-s*.xml
%{_libdir}/valgrind/s390-acr.xml
%{_libdir}/valgrind/s390-fpr-valgrind-s*.xml
%{_libdir}/valgrind/s390-fpr.xml
%{_libdir}/valgrind/s390-vx-valgrind-s*.xml
%{_libdir}/valgrind/s390-vx.xml
%{_libdir}/valgrind/mips-cp0-valgrind-s*.xml
%{_libdir}/valgrind/mips-cp0.xml
%{_libdir}/valgrind/mips-cpu-valgrind-s*.xml
%{_libdir}/valgrind/mips-cpu.xml
%{_libdir}/valgrind/mips-fpu-valgrind-s*.xml
%{_libdir}/valgrind/mips-fpu.xml
%{_libdir}/valgrind/mips-linux-valgrind.xml
%{_libdir}/valgrind/mips-linux.xml
%{_libdir}/valgrind/32bit-core.xml
%{_libdir}/valgrind/32bit-linux.xml
%{_libdir}/valgrind/32bit-sse.xml
%{_libdir}/valgrind/arm-core-valgrind-s*.xml
%{_libdir}/valgrind/arm-core.xml
%{_libdir}/valgrind/arm-vfpv3-valgrind-s*.xml
%{_libdir}/valgrind/arm-vfpv3.xml
%{_libdir}/valgrind/arm-with-vfpv3-valgrind.xml
%{_libdir}/valgrind/arm-with-vfpv3.xml
%{_libdir}/valgrind/32bit-core-valgrind-s*.xml
%{_libdir}/valgrind/32bit-linux-valgrind-s*.xml
%{_libdir}/valgrind/32bit-sse-valgrind-s*.xml
%{_libdir}/valgrind/i386-coresse-valgrind.xml
%{_libdir}/valgrind/i386-linux-valgrind.xml
%{_libdir}/valgrind/power-altivec-valgrind-s*.xml
%{_libdir}/valgrind/power-altivec.xml
%{_libdir}/valgrind/power-core.xml
%{_libdir}/valgrind/power-fpu-valgrind-s*.xml
%{_libdir}/valgrind/power-fpu.xml
%{_libdir}/valgrind/power-linux-valgrind-s*.xml
%{_libdir}/valgrind/power-linux.xml
%{_libdir}/valgrind/power-vsx-valgrind-s1.xml
%{_libdir}/valgrind/power-vsx-valgrind-s2.xml
%{_libdir}/valgrind/power-vsx.xml
%{_libdir}/valgrind/powerpc-altivec32l-valgrind.xml
%{_libdir}/valgrind/powerpc-altivec32l.xml
%{_libdir}/valgrind/powerpc-altivec64l-valgrind.xml
%{_libdir}/valgrind/powerpc-altivec64l.xml

%changelog
* Wed May  8 2019 Dirk Mueller <dmueller@suse.com>
- update to 3.15.0 (fate#327402):
  3.15.0 is a feature release with many improvements and the usual collection of
  bug fixes.
  This release supports X86/Linux, AMD64/Linux, ARM32/Linux, ARM64/Linux,
  PPC32/Linux, PPC64BE/Linux, PPC64LE/Linux, S390X/Linux, MIPS32/Linux,
  MIPS64/Linux, ARM/Android, ARM64/Android, MIPS32/Android, X86/Android,
  X86/Solaris, AMD64/Solaris and AMD64/MacOSX 10.12.  There is also preliminary
  support for X86/macOS 10.13 and AMD64/macOS 10.13.
  * ==================== CORE CHANGES ===================
  * The XTree Massif output format now makes use of the information obtained
  when specifying --read-inline-info=yes.
  * amd64 (x86_64): the RDRAND and F16C insn set extensions are now supported.
  * ==================== TOOL CHANGES ====================
  * DHAT:
  - DHAT been thoroughly overhauled, improved, and given a GUI.  As a result,
    it has been promoted from an experimental tool to a regular tool.  Run it
    with --tool=dhat instead of --tool=exp-dhat.
  - DHAT now prints only minimal data when the program ends, instead writing
    the bulk of the profiling data to a file.  As a result, the --show-top-n
    and --sort-by options have been removed.
  - Profile results can be viewed with the new viewer, dh_view.html.  When
    a run ends, a short message is printed, explaining how to view the result.
  - See the documentation for more details.
  * Cachegrind:
  - cg_annotate has a new option, --show-percs, which prints percentages next
    to all event counts.
  * Callgrind:
  - callgrind_annotate has a new option, --show-percs, which prints percentages
    next to all event counts.
  - callgrind_annotate now inserts commas in call counts, and
    sort the caller/callee lists in the call tree.
  * Massif:
  - The default value for --read-inline-info is now "yes" on
    Linux/Android/Solaris. It is still "no" on other OS.
  * Memcheck:
  - The option --xtree-leak=yes (to output leak result in xtree format)
    automatically activates the option --show-leak-kinds=all, as xtree
    visualisation tools such as kcachegrind can in any case select what kind
    of leak to visualise.
  - There has been further work to avoid false positives.  In particular,
    integer equality on partially defined inputs (C == and !=) is now handled
    better.
- remove 0001-Bug-385411-s390x-Add-z13-vector-floating-point-suppo.patch
  0001-Bug-385411-s390x-Tests-and-internals-for-z13-vector-.patch
  0001-Bug-397187-s390x-Add-vector-register-support-for-vgd.patch
  0001-Bug-399444-s390x-Drop-unnecessary-check-in-s390_irge.patch
  0001-Bug-400490-s390x-Fix-register-allocation-for-VRs-vs-.patch
  0001-Bug-400491-s390x-Sign-extend-immediate-operand-of-LO.patch
  0001-Bug-402519-POWER-3.0-addex-instruction-incorrectly-i.patch
  0001-Bug-403552-s390x-Fix-vector-facility-bit-number.patch
  0001-s390x-more-fixes.patch
  Implement-emulated-system-registers.-Fixes-392146.patch (all upstream)
* Wed Apr 24 2019 Martin Liška <mliska@suse.cz>
- Disable LTO (boo#1133288).
* Tue Feb 19 2019 Dirk Mueller <dmueller@suse.com>
- add 0001-Bug-385411-s390x-Add-z13-vector-floating-point-suppo.patch
  0001-Bug-385411-s390x-Tests-and-internals-for-z13-vector-.patch
  0001-Bug-399444-s390x-Drop-unnecessary-check-in-s390_irge.patch
  0001-Bug-403552-s390x-Fix-vector-facility-bit-number.patch (bsc#1124111)
* Sat Feb  9 2019 schwab@suse.de
- Don't package files twice on ppc64
* Wed Jan 16 2019 Michal Suchanek <msuchanek@suse.de>
- Fix POWER9 addex instruction emulation (bsc#1121025).
  0001-Bug-402519-POWER-3.0-addex-instruction-incorrectly-i.patch
* Fri Jan 11 2019 Dirk Mueller <dmueller@suse.com>
- split into a -32bit subpackage, fix buildrequires for older distros
* Thu Dec  6 2018 Bernhard Wiedemann <bwiedemann@suse.com>
- drop unreproducible unused .a files to make the package build
  reproducible (boo#1118163)
* Sun Nov 25 2018 olaf@aepfle.de
- update valgrind.xen.patch to branch bug390553-20181125-ddfc274b2
* Thu Nov 22 2018 Dirk Mueller <dmueller@suse.com>
- build against Toolchain module for SLE12
- add 0001-Bug-397187-s390x-Add-vector-register-support-for-vgd.patch
  0001-Bug-400490-s390x-Fix-register-allocation-for-VRs-vs-.patch,
  0001-Bug-400491-s390x-Sign-extend-immediate-operand-of-LO.patch,
  0001-s390x-more-fixes.patch,
  Implement-emulated-system-registers.-Fixes-392146.patch (FATE#326355)
- enable check (poo#36751)
* Wed Nov 21 2018 Dirk Mueller <dmueller@suse.com>
- update to 3.14.0 (bsc#1114575, FATE#326355):
  see http://www.valgrind.org/docs/manual/dist.news.html
  * The new option --keep-debuginfo=no|yes (default no) can be used to retain
    debug info for unloaded code.  This allows saved stack traces (e.g. for
    memory leaks) to include file/line info for code that has been dlclose'd (or
    similar).  See the user manual for more information and known limitations.
  * Ability to specify suppressions based on source file name and line number.
  * Majorly overhauled register allocator.  No end-user changes, but the JIT
    generates code a bit more quickly now.
  * Preliminary support for macOS 10.13 has been added.
  * mips: support for MIPS32/MIPS64 Revision 6 has been added.
  * mips: support for MIPS SIMD architecture (MSA) has been added.
  * mips: support for MIPS N32 ABI has been added.
  * s390: partial support for vector instructions (integer and string) has been
    added.
  * Helgrind: Addition of a flag
  - -delta-stacktrace=no|yes [yes on linux amd64/x86]
    which specifies how full history stack traces should be computed.
    Setting this to =yes can speed up Helgrind by 25%% when using
  - -history-level=full.
  * Memcheck: reduced false positive rate for optimised code created by Clang 6
    / LLVM 6 on x86, amd64 and arm64.  In particular, Memcheck analyses code
    blocks more carefully to determine where it can avoid expensive definedness
    checks without loss of precision.  This is controlled by the flag
  - -expensive-definedness-checks=no|auto|yes [auto].
  * Valgrind is now buildable with link-time optimisation (LTO).  A new
    configure option --enable-lto=yes allows building Valgrind with LTO.  If the
    toolchain supports it, this produces a smaller/faster Valgrind (up to 10%%).
    Note that if you are doing Valgrind development, --enable-lto=yes massively
    slows down the build process.
- remove epoll-wait-fix.patch,
  Fix-access-to-time-base-register-to-return-64-bits.patch,
  0001-Accept-read-only-PT_LOAD-segments-and-.rodata.patch (upstream),
* Tue Sep 25 2018 Michal Suchanek <msuchanek@suse.com>
- valgrind truncates powerpc timebase to 32-bits (bsc#1109589).
  Fix-access-to-time-base-register-to-return-64-bits.patch
* Thu Sep 13 2018 dmueller@suse.com
- valgrind.xen.patch: refresh
* Tue Aug 28 2018 stefan.bruens@rwth-aachen.de
- Filter out -m64 from optflags, breaks build of 32 bit parts
- Cleanup, remove suse_version < 1100 conditionals
- Use %%license for COPYING, COPYING.DOCS
* Mon Aug 27 2018 stefan.bruens@rwth-aachen.de
- Fix missing debuginfo with current binutils, boo#1103239
  0001-Accept-read-only-PT_LOAD-segments-and-.rodata.patch
* Fri Jun  8 2018 mbrugger@suse.com
- ad Implement-emulated-system-registers.-Fixes-392146.patch (bsc#1086543)
* Thu Feb 22 2018 olaf@aepfle.de
- add valgrind.xen.patch to handle Xen 4.10 (fate#321394, fate#322686)
* Mon Oct 30 2017 dmueller@suse.com
- add epoll-wait-fix.patch (bsc#1064958)
* Sun Jun 25 2017 dmueller@suse.com
- update to 3.13.0 (fate#321455):
  - remove fix-ppcl64-clobber-list.patch
  3.13.0 is a feature release with many improvements and the
  usual collection of bug fixes.
  See http://valgrind.org/docs/manual/dist.news.html
* Tue Apr 25 2017 mliska@suse.cz
- Add fix-ppcl64-clobber-list.patch: fix clobber list on ppcl64le,
  it's backport of upstream patch.
* Tue Dec 27 2016 foss@grueninger.de
- update to 3.12.0 (bsc#1017016, FATE#321455)
  * 3.12.0 is a feature release with many improvements and the usual
  collection of bug fixes. The full changelog can be found at
  http://valgrind.org/docs/manual/dist.news.html
  or
  /usr/share/doc/packages/valgrind/NEWS
- droped patches which are part of the release:
  gcc5.patch, r15702.diff, r15792.diff, r15802.diff, svn-r15766.patch,
  vex-r3197.diff, vex-r3210.diff, vex-r3213.diff
* Thu Oct 20 2016 stefan.bruens@rwth-aachen.de
- add vex-r3213.diff (kde#356393)
* Sat May 28 2016 dmueller@suse.com
- add vex-r3197.diff (bsc#981447)
* Wed Apr 20 2016 jslaby@suse.com
- The previous did not help, remove -strong first.
* Tue Apr 19 2016 meissner@suse.com
- also remove -fstack-protector-strong from the CFLAGS
* Fri Apr  1 2016 dmueller@suse.com
- add r15702.diff, r15792.diff, vex-r3210.diff, r15802.diff (fate#319608)
* Mon Feb 22 2016 schwab@suse.de
- glibc-version.patch: removed, no longer needed
* Mon Feb 15 2016 dmueller@suse.com
- update to 3.11.0 (fate#319608):
  * 3.11.0 is a feature release with many improvements and the usual
  collection of bug fixes.
- replace gcc-version.patch with gcc5.patch: This is the upstream
  version
- drop valgrind-linux-4.0.patch: merged upstream
- add svn-r15766.patch: Fix valgrind with recent kernels
- jit-register-unregister.diff commented out, needs porting
* Thu Aug  6 2015 schwab@suse.de
- glibc-version.patch: Add support for glibc 2.22.
* Fri Apr 24 2015 dimstar@opensuse.org
- Add valgrind-linux-4.0.patch: Fix build with linux kernel 4.0+.
  Taken from svn, rev 14955.
* Thu Apr  2 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Update to 3.10.1
  * bugfix release (for full list of solved issues see NEWS file)
* Thu Feb 12 2015 rguenther@suse.com
- gcc-version.patch: Add support for GCC 5.
* Mon Feb  9 2015 schwab@suse.de
- glibc-version.patch: Add support for glibc 2.21.
* Tue Sep 16 2014 schwab@suse.de
- glibc-2.19.patch: already upstream, so remove
- Fix file list
* Tue Sep 16 2014 dmueller@suse.com
- update to 3.10.0:
  * Support for the 64-bit ARM Architecture (AArch64 ARMv8).  This port
    is mostly complete, and is usable, but some SIMD instructions are as
    yet unsupported.
  * Support for little-endian variant of the 64-bit POWER architecture.
  * Support for Android on MIPS32.
  * Support for 64bit FPU on MIPS32 platforms.
  * Both 32- and 64-bit executables are supported on MacOSX 10.8 and 10.9.
  * Configuration for and running on Android targets has changed.
    See README.android in the source tree for details.
  - drop VEX-r2803.diff, VEX-r2808.diff, VEX-r2816.diff, VEX-r2858.diff,
  VEX-r2904.diff, VEX-r2910.diff, VEX-r2914.diff, VEX-r2915.diff,
  VEX-r2916.diff, aarch64-VEX-support.diff, aarch64-support.diff,
  r13767.diff, r13770.diff, r14184.diff, r14238.diff, r14239.diff,
  r14240.diff, r14246.diff, r2798.diff, valgrind-r13948.diff
* Sun Aug 17 2014 dmueller@suse.com
- update for ppc64le support (bnc#880334):
  - drop: valgrind-3.9.0-merge.patches.from.Paul.McKenney.patch,
  valgrind-3.9.0-ppc64le-abiv2.patch
  - add: VEX-r2803.diff, VEX-r2808.diff, VEX-r2816.diff
  VEX-r2904.diff, VEX-r2910.diff, VEX-r2914.diff, VEX-r2915.diff,
  VEX-r2916.diff, r13767.diff, r13770.diff, r14184.diff, r14238.diff,
  r14239.diff, r14240.diff, r14246.diff
* Sat Jul 26 2014 schwab@suse.de
- Fix patch conflicts.
* Wed Jun 18 2014 dmueller@suse.com
- add VEX-r2858.diff, valgrind-r13948.diff for (bnc#883157)
* Sun May 18 2014 schwab@suse.de
- Update aarch64-support.diff, aarch64-VEX-support.diff from svn
* Thu Apr 24 2014 dmueller@suse.com
- add aarch64-support.diff, aarch64-VEX-support.diff: aarch64 support
* Tue Feb 18 2014 dmueller@suse.com
- added patches:
  * r2798.diff
* Tue Feb 11 2014 schwab@suse.de
- glibc-2.19.patch: add support for glibc 2.19
* Mon Jan 13 2014 normand@linux.vnet.ibm.com
- add support of ppc64le architecture
- added patches:
  * valgrind-3.9.0-merge.patches.from.Paul.McKenney.patch
  * valgrind-3.9.0-ppc64le-abiv2.patch
* Fri Jan  3 2014 dmueller@suse.com
- add armv6-support.diff: Add support for armv6hl
* Wed Nov  6 2013 burnus@net-b.de
- update to 3.9.0:
  * Support for Intel AVX2 instructions.  This is available only on 64
  bit code.
  * Support for POWER8 (Power ISA 2.07) instructions.
  * Initial support for Intel Transactional Synchronization Extensions,
  both RTM and HLE.
  * Initial support for Hardware Transactional Memory on POWER.
  * Improvements in handling of vectorised code, leading to
  significantly fewer false error reports.  You need to use the flag
  - -partial-loads-ok=yes to get the benefits of these changes.
  * Better control over the leak checker.  It is now possible to
  specify which leak kinds (definite/indirect/possible/reachable)
  should be displayed.
  * Reduced "possible leak" reports from the leak checker by the use
  of better heuristics.
  * Better control of stacktrace acquisition for heap-allocated
  blocks.
  * Better reporting of leak suppression usage.
  * New and modified GDB server monitor features.
  * New flag --sigill-diagnostics to control whether a diagnostic
  message is printed when the JIT encounters an instruction it can't
  translate.
  * The maximum amount of memory that Valgrind can use on 64 bit
  targets has been increased from 32GB to 64GB.
  * Additional smaller new features and many bug fixes.
- Remove obsolete raise-segnames-limit.diff,
  valgrind-glibc-2.17.patch and valgrind-glibc-2.18.patch.
* Tue Aug 13 2013 schwab@suse.de
- valgrind-glibc-2.18.patch: add support for glibc 2.18
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Mon Dec 31 2012 idonmez@suse.com
- Fix last patch
* Mon Dec 31 2012 idonmez@suse.com
- Add valgrind-glibc-2.17.patch to fix compilation with glibc 2.17
* Thu Oct  4 2012 dmueller@suse.com
- raise seglimit to make it more useful for some apps
* Thu Sep 20 2012 burnus@net-b.de
- update to 3.8.1 (bnc#776211):
  * Fixes some assertion failures.
  * Support for some missing instructions on ARM.
  * Support instructions MOVAPS and TZCNT.
  * Bug fixes.
* Wed Sep  5 2012 dmueller@suse.com
- update to 3.8.0 (FATE#314090):
  * Support for MIPS32 platforms running Linux.  Valgrind has been
  tested on MIPS32 and MIPS32r2 platforms running different Debian
  Squeeze and MeeGo distributions.  Both little-endian and big-endian
  cores are supported.  The tools Memcheck, Massif and Lackey have
  been tested and are known to work. See README.mips for more details.
  * Preliminary support for Android running on x86.
  * Preliminary (as-yet largely unusable) support for MacOSX 10.8.
  * Support for Intel AVX instructions and for AES instructions.  This
  support is available only for 64 bit code.
  * Support for POWER Decimal Floating Point instructions.
  * Non-libc malloc implementations are now supported.  This is useful
  for tools that replace malloc (Memcheck, Massif, DRD, Helgrind).
  Using the new option --soname-synonyms, such tools can be informed
  that the malloc implementation is either linked statically into the
  executable, or is present in some other shared library different
  from libc.so.  This makes it possible to process statically linked
  programs, and programs using other malloc libraries, for example
  TCMalloc or JEMalloc.
  * For tools that provide their own replacement for malloc et al, the
  option --redzone-size=<number> allows users to specify the size of
  the padding blocks (redzones) added before and after each client
  allocated block.  Smaller redzones decrease the memory needed by
  Valgrind.  Bigger redzones increase the chance to detect blocks
  overrun or underrun.  Prior to this change, the redzone size was
  hardwired to 16 bytes in Memcheck.
  * Memcheck:
  - The leak_check GDB server monitor command now can
    control the maximum nr of loss records to output.
  - Reduction of memory use for applications allocating
    many blocks and/or having many partially defined bytes.
  - Addition of GDB server monitor command 'block_list' that lists
    the addresses/sizes of the blocks of a leak search loss record.
  - Addition of GDB server monitor command 'who_points_at' that lists
    the locations pointing at a block.
  - If a redzone size > 0 is given, VALGRIND_MALLOCLIKE_BLOCK now will
    detect an invalid access of these redzones, by marking them
    noaccess.  Similarly, if a redzone size is given for a memory
    pool, VALGRIND_MEMPOOL_ALLOC will mark the redzones no access.
    This still allows to find some bugs if the user has forgotten to
    mark the pool superblock noaccess.
  - Performance of memory leak check has been improved, especially in
    cases where there are many leaked blocks and/or many suppression
    rules used to suppress leak reports.
  - Reduced noise (false positive) level on MacOSX 10.6/10.7, due to
    more precise analysis, which is important for LLVM/Clang
    generated code.  This is at the cost of somewhat reduced
    performance.  Note there is no change to analysis precision or
    costs on Linux targets.
  * DRD:
  - Added even more facilities that can help finding the cause of a data
    race, namely the command-line option --ptrace-addr and the macro
    DRD_STOP_TRACING_VAR(x). More information can be found in the manual.
  - Fixed a subtle bug that could cause false positive data race reports.
  * The C++ demangler has been updated so as to work well with C++
  compiled by up to at least g++ 4.6.
  * Tool developers can make replacement/wrapping more flexible thanks
  to the new option --soname-synonyms.  This was reported above, but
  in fact is very general and applies to all function
  replacement/wrapping, not just to malloc-family functions.
  * Round-robin scheduling of threads can be selected, using the new
  option --fair-sched= yes.  Prior to this change, the pipe-based
  thread serialisation mechanism (which is still the default) could
  give very unfair scheduling.  --fair-sched=yes improves
  responsiveness of interactive multithreaded applications, and
  improves repeatability of results from the thread checkers Helgrind
  and DRD.
  * For tool developers: support to run Valgrind on Valgrind has been
  improved.  We can now routinely Valgrind on Helgrind or Memcheck.
  * gdbserver now shows the float shadow registers as integer
  rather than float values, as the shadow values are mostly
  used as bit patterns.
  * Increased limit for the --num-callers command line flag to 500.
  * Performance improvements for error matching when there are many
  suppression records in use.
  * Improved support for DWARF4 debugging information (bug 284184).
  * Initial support for DWZ compressed Dwarf debug info.
  * Improved control over the IR optimiser's handling of the tradeoff
  between performance and precision of exceptions.  Specifically,
  - -vex-iropt-precise-memory-exns has been removed and replaced by
  - -vex-iropt-register-updates, with extended functionality.  This
  allows the Valgrind gdbserver to always show up to date register
  values to GDB.
  * Modest performance gains through the use of translation chaining for
  JIT-generated code.
* Fri Aug 17 2012 burnus@net-b.de
- Support TZCNT/LZCNT instructions, generated by GCC 4.8,
  by falling back to BSF/BSR. (bnc#776211)
* Sun Jul 22 2012 aj@suse.de
- Support glibc 2.16.
* Mon Jun  4 2012 dmueller@suse.com
- arch is now armv7hl
* Tue May 15 2012 sndirsch@suse.com
- add "BuildRequires: pkgconfig" so the provides for
  "pkgconfig(valgrind)" gets created again
* Thu May 10 2012 vuntz@opensuse.org
- Remove xorg-x11-devel BuildRequires: I can only guess it was
  there to make sure the xfree supp files are used, but they are
  used anyway by default. This helps resolve a build loop between
  libdrm and valgrind.
* Thu Apr 26 2012 joop.boonen@opensuse.org
- Added patch valgrind-3.7.0-automake-1.11.2.patch to fix automake issue
  * See https://bugs.kde.org/show_bug.cgi?id=290719
* Thu Dec 29 2011 dmueller@suse.de
- fix build against glibc 2.15
* Mon Dec 19 2011 adrian@suse.de
- build only on armv7l, not armv5
* Wed Nov 30 2011 coolo@suse.com
- add automake as buildrequire to avoid implicit dependency
* Wed Nov  9 2011 dmueller@suse.de
- update to 3.7.0 (bnc#724215):
  * Support for IBM z/Architecture (s390x) running Linux.  Valgrind can
  analyse 64-bit programs running on z/Architecture.  Most user space
  instructions up to and including z10 are supported.
  See README.s390 for more details.
  * Support for the IBM Power ISA 2.06 (Power7 instructions)
  * Further solidification of support for SSE 4.2 in 64-bit mode
  * Memcheck:
  * - reduction of memory use in some circumstances
  * - improved handling of freed memory for finding more errors
  * - fix of a longstanding bug that could cause false negatives
  * Helgrind:
  * - Helgrind: performance improvements and major memory use reductions
  * GDB server: Valgrind now has an embedded GDB server.  That means it
  is possible to control a Valgrind run from GDB, doing all the usual
  things that GDB can do (single stepping, breakpoints, examining
  data, etc).  Tool-specific functionality is also available.
  * Over 160 bugs have been fixed.
* Mon Oct 24 2011 ro@suse.de
- fix build on ppc (32bit)
* Sun Oct  2 2011 dmueller@suse.de
- enable build on %%%%arm
* Fri Aug 19 2011 dmueller@suse.de
- fix build against glibc 2.14
- require the right version of glibc at runtime (part of fix for bnc#700362)
* Tue Jul  5 2011 aj@suse.de
- Support Linux kernel 3.x (bnc#724215)
* Wed Jun 22 2011 dmueller@suse.de
- fix merge error
* Sat Jun 18 2011 dmueller@suse.de
- Improve Valgrind POWER6 and POWER7/P7 support (bnc#700358)
* Tue May 17 2011 stefan.bruens@rwth-aachen.de
- revert removal for gcc-32bit requirement, breaks valgrinding
  32bit code on 64bit archs (bnc#705405)
* Mon Apr 11 2011 dmueller@suse.de
- fix testsuite for s390 (kde#264800, kde#265762, kde#253206)
- Add folding rules for Clz32 and Clz64 (kde#243404)
- Refresh s390x port (kde#243404)
* Wed Mar 16 2011 dmueller@suse.de
- update to 3.6.1 (bnc#679106):
  3.6.1 is a bug fix release.  It adds support for some SSE4
  instructions that were omitted in 3.6.0 due to lack of time.  Initial
  support for glibc-2.13 has been added.  A number of bugs causing
  crashing or assertion failures have been fixed.
* Fri Oct 22 2010 dmueller@suse.de
- update to 3.6.0:
  3.6.0 is a feature release with many significant improvements and the
  usual collection of bug fixes. See the NEWS file for details.
* Thu Oct 21 2010 dmueller@suse.de
- apparently gcc-32bit does not exist on old code streams, but
  it seems to work without it as well
* Wed Oct 20 2010 dmueller@suse.de
- disable building docs until I find a way to build them without
  network access
* Wed Oct 13 2010 dmueller@suse.de
- add s390x port (FATE#310036)
- update to 3.6.0 snapshot:
  - Valgrind runs much faster when the --smc-check=all option is given.
  - Cachegrind has a new processing script, cg_diff, which finds the
    difference between two profiles.  It's very useful for evaluating the
    performance effects of a change in a program.
    Related to this change, the meaning of cg_annotate's (rarely-used)
  - -threshold option has changed; this is unlikely to affect many people, if
    you do use it please see the user manual for details.
  - Callgrind now can do branch prediction simulation, similar to Cachegrind.
    In addition, it optionally can count the number of executed global bus events.
    Both can be used for a better approximation of a "Cycle Estimation" as
    derived event (you need to update the event formula in KCachegrind yourself).
  - Cachegrind and Callgrind now refer to the LL (last-level) cache rather
    than the L2 cache.  This is to accommodate machines with three levels of
    caches -- if Cachegrind/Callgrind auto-detects the cache configuration of
    such a machine it will run the simulation as if the L2 cache isn't
    present.  This means the results are less likely to match the true result
    for the machine, but Cachegrind/Callgrind's results are already only
    approximate, and should not be considered authoritative.  The results are
    still useful for giving a general idea about a program's locality.
  - Massif has a new option, --pages-as-heap, which is disabled by default.
    When enabled, instead of tracking allocations at the level of heap blocks
    (as allocated with malloc/new/new[]), it instead tracks memory allocations
    at the level of memory pages (as mapped by mmap, brk, etc).  Each mapped
    page is treated as its own block.  Interpreting the page-level output is
    harder than the heap-level output, but this option is useful if you want
    to account for every byte of memory used by a program.
  - Added new memcheck command-line option --show-possibly-lost.
  - Support for analyzing programs running under Wine with has been improved.
    The header files <valgrind/valgrind.h>, <valgrind/memcheck.h> and
    <valgrind/drd.h> can now be used in Windows-programs compiled with MinGW
    or one of the Microsoft Visual Studio compilers.
  - DRD does now have two new command-line options: --free-is-write and
  - -trace-alloc. The former allows to detect reading from already freed
    memory, and the latter allows to trace all memory allocations and
    deallocations.
  - Several new annotations have been added in DRD: custom barrier
    implementations can now be annotated and benign races on static variables
    too.
  - The happens before / happens after annotations in DRD have been made more
    powerful such that these can now also be used to annotate e.g. a smart
    pointer implementation.
* Thu Sep 23 2010 dmueller@suse.de
- increase stack size (bnc#640793)
* Fri May  7 2010 dmueller@suse.de
- fix build for ppc64
* Mon Apr 26 2010 dmueller@suse.de
- handle pthread apps better (bnc#599585)
- prefer CFI for better stack unwinding (bnc#559061)
* Fri Mar 26 2010 dmueller@suse.de
- handle inotify_init1 (bnc#558964)
* Wed Jan  6 2010 dmueller@suse.de
- fix build against glibc 2.11
* Wed Dec  2 2009 dmueller@suse.de
- update and reenable jit-register-unregister.diff
* Tue Nov  3 2009 coolo@novell.com
- updated patches to apply with fuzz=0
* Tue Sep  8 2009 dmueller@suse.de
- update to 3.5.0:
  * Support for glibc 2.10, gcc 4.5 has been added.
  * Improvements and simplifications to Memcheck's leak checker.
  * Clarification and simplifications in various aspects of Valgrind's
    text output.
  * XML output for Helgrind and Ptrcheck.
  * Performance and stability improvements for Helgrind and DRD.
  * Genuinely atomic support for x86/amd64/ppc atomic instructions.
  * A new experimental tool, BBV, useful for computer architecture
    research.
  * Improved Wine support, including ability to read Windows PDB
    debuginfo.
* Fri Mar 13 2009 dmueller@suse.de
- update to 3.4.1 (bnc#479701):
  * 3.4.1 is a bug-fix release that fixes some regressions and
  assertion failures in debug info reading in 3.4.0, most notably
  incorrect stack traces on amd64-linux on older (glibc-2.3 based)
  systems. Various other debug info problems are also fixed. A
  number of bugs in the exp-ptrcheck tool introduced in 3.4.0
  have been fixed.
* Fri Jan 23 2009 dmueller@suse.de
- update to 3.4.0:
  * http://www.valgrind.org/docs/manual/dist.news.html
* Sat Nov 22 2008 dmueller@suse.de
- update suppressions
* Wed Nov 19 2008 dmueller@suse.de
- fix .valgrindrc reading vulnerability (CVE-2008-4865, bnc#445013)
- add support for glibc 2.9
* Wed Nov  5 2008 dmueller@suse.de
- add syscall wrappers for pipe2
* Tue Jun 24 2008 schwab@suse.de
- Add fadvice64 wrapper.
* Sun Jun 22 2008 dmueller@suse.de
- update to 3.3.1:
    n-i-bz  Massif segfaults at exit
    n-i-bz  Memcheck asserts on Altivec code
    n-i-bz  fix sizeof bug in Helgrind
    n-i-bz  check fd on sys_llseek
    n-i-bz  update syscall lists to kernel 2.6.23.1
    n-i-bz  support sys_sync_file_range
    n-i-bz  handle sys_sysinfo, sys_getresuid, sys_getresgid on ppc64-linux
    n-i-bz  intercept memcpy in 64-bit ld.so's
    n-i-bz  Fix wrappers for sys_{futimesat,utimensat}
    n-i-bz  Minor false-error avoidance fixes for Memcheck
    n-i-bz  libmpiwrap.c: add a wrapper for MPI_Waitany
    n-i-bz  helgrind support for glibc-2.8
    n-i-bz  partial fix for mc_leakcheck.c:698 assert:
    'lc_shadows[i]->data + lc_shadows[i] ...
    n-i-bz  Massif/Cachegrind output corruption when programs fork
    n-i-bz  register allocator fix: handle spill stores correctly
    n-i-bz  add support for PA6T PowerPC CPUs
    126389  vex x86->IR: 0xF 0xAE (FXRSTOR)
    158525  ==126389
    152818  vex x86->IR: 0xF3 0xAC (repz lodsb)
    153196  vex x86->IR: 0xF2 0xA6 (repnz cmpsb)
    155011  vex x86->IR: 0xCF (iret)
    155091  Warning [...] unhandled DW_OP_ opcode 0x23
    156960  ==155901
    155528  support Core2/SSSE3 insns on x86/amd64
    155929  ms_print fails on massif outputs containing long lines
    157665  valgrind fails on shmdt(0) after shmat to 0
    157748  support x86 PUSHFW/POPFW
    158212  helgrind: handle pthread_rwlock_try{rd,wr}lock.
    158425  sys_poll incorrectly emulated when RES==0
    158744  vex amd64->IR: 0xF0 0x41 0xF 0xC0 (xaddb)
    160907  Support for a couple of recent Linux syscalls
    161285  Patch -- support for eventfd() syscall
    161378  illegal opcode in debug libm (FUCOMPP)
    160136  ==161378
    161487  number of suppressions files is limited to 10
    162386  ms_print typo in milliseconds time unit for massif
    161036  exp-drd: client allocated memory was never freed
    162663  signalfd_wrapper fails on 64bit linux
* Sun Apr 27 2008 dmueller@suse.de
- update glibc 2.8 support
* Sun Dec 16 2007 dmueller@suse.de
- readd deprecated #define's (#348337)
* Tue Dec 11 2007 dmueller@suse.de
- update to 3.3.0 (final):
  * last minute bugfixes
* Thu Dec  6 2007 dmueller@suse.de
- update jit-support patch
* Mon Dec  3 2007 dmueller@suse.de
- update to 3.3.0 RC1:
  - Helgrind works again
  - Massif has been majorly overhauled
  - Cachegrind now does branch-prediction profiling
  - New experimental tools Omega and DRD
  - Many small refinements to stability, scalability and performance
  - Somewhat restructured documentation
  - Many bug fixes
* Mon Nov 26 2007 dmueller@suse.de
- fix build against glibc 2.7
* Fri Sep 14 2007 dmueller@suse.de
- fix divisions by zero in massif (#310234)
* Wed Sep 12 2007 dmueller@suse.de
- fix build on ppc64 again
- update suppressions
* Fri Aug 24 2007 dmueller@suse.de
- fix valgrind on x86_64 (#296803)
* Tue Aug 21 2007 dmueller@suse.de
- suppression update
* Mon Jul 23 2007 dmueller@suse.de
- update suppression file
* Mon Jul  9 2007 dmueller@suse.de
- support JIT runtimes (#289490)
* Tue Jul  3 2007 dmueller@suse.de
- update suppression file (#287090)
* Wed May 23 2007 dmueller@suse.de
- build against glibc 2.6
* Thu Apr  5 2007 dmueller@suse.de
- split into -devel subpackage
* Fri Mar 30 2007 dmueller@suse.de
- add patch to track undefinedness in environment (#249676)
* Tue Jan 30 2007 dmueller@suse.de
- update to 3.2.3:
  * fixes two serious regressions introduced in 3.2.2
  * intercept stpcpy_chk (#234247)
- fix openat syscall wrapper (#240225)
* Thu Jan 25 2007 dmueller@suse.de
- intercept stpcpy_chk and memrchr as well (#234347)
* Tue Jan 23 2007 dmueller@suse.de
- switch to gcc-32bit on x86_64
* Mon Jan 22 2007 dmueller@suse.de
- update to 3.2.2:
  * many fixes for ppc 32/64 (#fate 301640)
* Tue Oct 17 2006 dmueller@suse.de
- disable omega plugin for ppc/ppc64
* Mon Oct 16 2006 dmueller@suse.de
- update to 3.2 BRANCH:
  * support glibc 2.5
  * update suppressions
- add omega plugin
* Fri Sep 15 2006 dmueller@suse.de
- update to 3.2.1:
  * suppresion updates
* Fri Sep 15 2006 dmueller@suse.de
- update to 3.2.1rc1:
  * about 36 bugfixes
* Wed Sep 13 2006 stbinner@suse.de
- fix build with < Factory
* Mon Aug 28 2006 dmueller@suse.de
- fix suppressions
- update drd plugin
* Thu Aug 24 2006 dmueller@suse.de
- add experimental drd plugin
- fix build on x86_64
* Wed Aug  2 2006 dmueller@suse.de
- also fix multibyte NOP parsing for x86_64
* Tue Aug  1 2006 dmueller@suse.de
- add patch to handle multibyte NOPs as generated by
  recent binutils
* Wed Jun  7 2006 dmueller@suse.de
- update to 3.2.0 final
  * only marginal changes since rc1
* Tue May 30 2006 dmueller@suse.de
- update to 3.2.0 rc1:
  * ppc64 support
  * callgrind now integrated part
  * massive performance improvements
  * lots of emulation fixlets
* Thu Mar 16 2006 dmueller@suse.de
- update to 3.1.1 (FATE #300493)
* Mon Mar  6 2006 dmueller@suse.de
- various updates from branch to fix PPC32 support
* Mon Feb  6 2006 dmueller@suse.de
- Fix GDB support
* Mon Feb  6 2006 dmueller@suse.de
- Reduce BuildRequires
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan  4 2006 dmueller@suse.de
- update to 3.1 branch
* Fri Dec  9 2005 dmueller@suse.de
- fix strict-aliasing issue
* Mon Nov 28 2005 dmueller@suse.de
- 3.1.0 final update
* Mon Nov 21 2005 dmueller@suse.de
- 3.1.0 RC1 update
* Thu Nov 10 2005 dmueller@suse.de
- update to 3.1 SVN
* Tue Nov  8 2005 dmueller@suse.de
- add hack to make valgrind work with apps that require executable stack
* Thu Sep 15 2005 dmueller@suse.de
- update 3.0.1 final
* Wed Aug 24 2005 dmueller@suse.de
- make massif work again
* Sun Aug 21 2005 dmueller@suse.de
- fix trace-children=yes failure
- add default suppressions for SL 10
* Mon Aug 15 2005 dmueller@suse.de
- regenerate VEX offset headers, otherwise it just hangs
* Fri Aug 12 2005 dmueller@suse.de
- update to 3.0 branch to make it work on non-SSE platforms (#104181)
* Fri Aug  5 2005 dmueller@suse.de
- initial package of 3.0
